@@ -9,7 +9,7 @@ from darwin.config import Config
 from darwin.dataset import RemoteDataset
 from darwin.dataset.identifier import DatasetIdentifier
 from darwin.exceptions import InsufficientStorage, InvalidLogin, MissingConfig, NotFound, Unauthorized
-from darwin.utils import is_deprecated_project_dir, is_project_dir, urljoin
+from darwin.utils import is_project_dir, urljoin
 from darwin.validators import name_taken, validation_error
 
 
@@ -233,22 +233,6 @@ class Client:
                 if project_path.is_dir() and is_project_dir(project_path):
                     yield Path(project_path)
 
-    def list_deprecated_local_datasets(self, team: Optional[str] = None) -> Iterator[Path]:
-        """Returns a list of all local folders which are detected as datasets but use a deprecated local structure
-
-        Returns
-        -------
-        list[Path]
-        List of all local datasets
-        """
-        team = team or self.default_team
-        team_config = self.config.get_team(team)
-
-        projects_team = Path(team_config["datasets_dir"])
-        for project_path in projects_team.glob("*"):
-            if project_path.is_dir() and is_deprecated_project_dir(project_path):
-                yield Path(project_path)
-
     def list_remote_datasets(self, team: Optional[str] = None) -> Iterator[RemoteDataset]:
         """Returns a list of all available datasets with the team currently authenticated against
 
@@ -370,7 +354,7 @@ class Client:
         return self.config.get_team(team or self.default_team)["datasets_dir"]
 
     def set_datasets_dir(self, datasets_dir: Path, team: Optional[str] = None):
-        """ Sets the dataset directory of the specified team or the default one
+        """Sets the dataset directory of the specified team or the default one
 
         Parameters
         ----------
@@ -487,7 +471,7 @@ class Client:
 
     @staticmethod
     def _decode_response(response, debug: bool = False):
-        """ Decode the response as JSON entry or return a dictionary with the error
+        """Decode the response as JSON entry or return a dictionary with the error
 
         Parameters
         ----------
