@@ -9,6 +9,7 @@ from upolygon import draw_polygon, rle_encode
 import darwin.datatypes as dt
 from darwin.utils import convert_polygons_to_sequences
 
+
 class NumpyEncoder(json.JSONEncoder):
     def default(self, obj):
         if isinstance(obj, np.integer):
@@ -161,7 +162,7 @@ def build_annotation(annotation_file, annotation_id, annotation: dt.Annotation,
             "id": annotation_id,
             "image_id": annotation_file.seq,
             "category_id": categories[annotation.annotation_class.name],
-            "segmentation": {"counts": counts, "size": [annotation_file.image_width, annotation_file.image_height]},
+            "segmentation": {"counts": counts, "size": [annotation_file.image_height, annotation_file.image_width]},
             "area": 0,
             "bbox": [min_x, min_y, w, h],
             "iscrowd": 1,
