@@ -2,7 +2,6 @@ import json
 from pathlib import Path
 from typing import List, Optional
 
-import numpy as np
 from upolygon import find_contours, rle_decode
 
 import darwin.datatypes as dt
@@ -35,7 +34,7 @@ def parse_json(path, data):
         image = image_lookup_table[image_id]
         annotations = list(filter(None, image_annotations[image_id]))
         annotation_classes = set([annotation.annotation_class for annotation in annotations])
-        yield dt.AnnotationFile(path, image["file_name"], annotation_classes, annotations)
+        yield dt.AnnotationFile(path, image["file_name"], annotation_classes, annotations, remote_path = "/")
 
 
 def parse_annotation(annotation, category_lookup_table):
@@ -50,12 +49,20 @@ def parse_annotation(annotation, category_lookup_table):
     if len(segmentation) == 0 and len(annotation["bbox"]) == 4:
         x, y, w, h = map(int, annotation["bbox"])
         return dt.make_bounding_box(category["name"], x, y, w, h)
-    elif len(segmentation) > 1:
+    elif isinstance(segmentation, dict):
         print("warning, converting complex coco rle mask to polygon, could take some time")
-        mask = rle_decode(segmentation["counts"], segmentation["size"])
+        if isinstance(segmentation["counts"], list):
+            mask = rle_decode(segmentation["counts"], segmentation["size"][::-1])
+        else:
+            counts = decode_binary_rle(segmentation["counts"])
+            mask = rle_decode(counts, segmentation["size"][::-1])
+
         _labels, external, _internal = find_contours(mask)
         paths = []
         for external_path in external:
+            # skip paths with less than 2 points
+            if len(external_path) // 2 <= 2:
+                continue
             path = []
             points = iter(external_path)
             while True:
@@ -66,9 +73,9 @@ def parse_annotation(annotation, category_lookup_table):
                     break
             paths.append(path)
         return dt.make_complex_polygon(category["name"], paths)
-    elif len(segmentation) == 1:
+    elif isinstance(segmentation, list):
         path = []
-        points = iter(segmentation[0])
+        points = iter(segmentation[0] if isinstance(segmentation[0], list) else segmentation)
         while True:
             try:
                 x, y = next(points), next(points)
@@ -80,12 +87,28 @@ def parse_annotation(annotation, category_lookup_table):
         return None
 
 
-def rle_decoding(counts, shape):
-    img = np.zeros(shape[0] * shape[1], dtype=np.uint8)
-    val = 1
-    n = 0
-    for pos in range(len(counts)):
-        val = not val
-        img[n : n + counts[pos]] = val
-        n += counts[pos]
-    return img.reshape(shape).T
+def decode_binary_rle(data):
+    """
+    decodes binary rle to integer list rle
+    """
+    m = len(data)
+    cnts = [0] * m
+    h = 0
+    p = 0
+    while p < m:
+        x = 0
+        k = 0
+        more = 1
+        while more > 0:
+            c = ord(data[p]) - 48
+            x |= (c & 0x1F) << 5 * k
+            more = c & 0x20
+            p = p + 1
+            k = k + 1
+            if more == 0 and (c & 0x10) != 0:
+                x |= -1 << 5 * k
+        if h > 2:
+            x += cnts[h - 2]
+        cnts[h] = x
+        h += 1
+    return cnts[0:h]
