@@ -52,22 +52,6 @@ def is_project_dir(project_path: Path) -> bool:
     return (project_path / "releases").exists() and (project_path / "images").exists()
 
 
-def is_deprecated_project_dir(project_path: Path) -> bool:
-    """Verifies if the directory is a project from Darwin that uses a deprecated local structure
-
-    Parameters
-    ----------
-    project_path : Path
-        Directory to examine
-
-    Returns
-    -------
-    bool
-        Is the directory a project from Darwin?
-    """
-    return (project_path / "annotations").exists() and (project_path / "images").exists()
-
-
 def get_progress_bar(array: List, description: Optional[str] = None):
     pbar = tqdm(array)
     pbar.set_description(desc=description, refresh=True)
@@ -136,7 +120,6 @@ def find_files(
     files_to_exclude = set(files_to_exclude)
     return [f for f in found_files if f.name not in files_to_exclude and str(f) not in files_to_exclude]
 
-
 def secure_continue_request() -> bool:
     """Asks for explicit approval from the user. Empty string not accepted"""
     return input("Do you want to continue? [y/N] ") in ["Y", "y"]
@@ -179,7 +162,7 @@ def parse_darwin_json(path: Union[str, Path], count: int):
     path = Path(path)
     with path.open() as f:
         data = json.load(f)
-        if not data["annotations"]:
+        if "annotations" not in data:
             return None
         if "fps" in data["image"] or "frame_count" in data["image"]:
             return parse_darwin_video(path, data, count)
@@ -197,11 +180,13 @@ def parse_darwin_image(path, data, count):
         annotation_classes,
         annotations,
         False,
-        data["image"]["width"],
-        data["image"]["height"],
-        data["image"]["url"],
+        data["image"].get("width"),
+        data["image"].get("height"),
+        data["image"].get("url"),
         data["image"].get("workview_url"),
         data["image"].get("seq", count),
+        None,
+        data["image"].get("path"),
     )
 
 
@@ -218,12 +203,13 @@ def parse_darwin_video(path, data, count):
         annotation_classes,
         annotations,
         True,
-        data["image"]["width"],
-        data["image"]["height"],
-        data["image"]["url"],
+        data["image"].get("width"),
+        data["image"].get("height"),
+        data["image"].get("url"),
         data["image"].get("workview_url"),
         data["image"].get("seq", count),
-        data["image"]["frame_urls"],
+        data["image"].get("frame_urls"),
+        data["image"].get("path"),
     )
 
 
@@ -283,7 +269,10 @@ def parse_darwin_video_annotation(annotation: dict):
         frame_annotations[int(f)] = parse_darwin_annotation({**frame, **{"name": name}})
         keyframes[int(f)] = frame.get("keyframe", False)
 
-    return dt.make_video_annotation(frame_annotations, keyframes, annotation["segments"], annotation.get("interpolated", False))
+    return dt.make_video_annotation(
+        frame_annotations, keyframes, annotation["segments"], annotation.get("interpolated", False)
+    )
+
 
 def split_video_annotation(annotation):
     if not annotation.is_video:
