@@ -2,7 +2,9 @@ from darwin.exceptions import NameTaken, ValidationError
 
 
 def name_taken(code, body):
-    if code == 422 and body["errors"]["metadata"][0] == "has already been taken":
+    if code != 422:
+        return
+    if body.get("errors", {}).get("name") == ["has already been taken"]:
         raise NameTaken
 
 
